@@ -66,6 +66,7 @@ use App::Dochazka::CLI::Commands::History qw(
 use App::Dochazka::CLI::Commands::Interval qw(
     interval_date
     interval_date_date1
+    interval_fillup_tsrange
     interval_month
     interval_num_num1
     interval_promptdate
@@ -367,18 +368,18 @@ our $dispatch_map = {
     "PUT INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
     "POST INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
     "DELETE INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
-    "GET INTERVAL FILLUP EID _NUM _DATE _DATE1" => \&_method_interval_fillup_eid,
-    "PUT INTERVAL FILLUP EID _NUM _DATE _DATE1" => \&_method_interval_fillup_eid,
-    "POST INTERVAL FILLUP EID _NUM _DATE _DATE1" => \&_method_interval_fillup_eid,
-    "DELETE INTERVAL FILLUP EID _NUM _DATE _DATE1" => \&_method_interval_fillup_eid,
-    "GET INTERVAL FILLUP NICK _TERM _DATE _DATE1" => \&_method_interval_fillup_nick,
-    "PUT INTERVAL FILLUP NICK _TERM _DATE _DATE1" => \&_method_interval_fillup_nick,
-    "POST INTERVAL FILLUP NICK _TERM _DATE _DATE1" => \&_method_interval_fillup_nick,
-    "DELETE INTERVAL FILLUP NICK _TERM _DATE _DATE1" => \&_method_interval_fillup_nick,
-    "GET INTERVAL FILLUP SELF _DATE _DATE1" => \&_method_interval_fillup_self,
-    "PUT INTERVAL FILLUP SELF _DATE _DATE1" => \&_method_interval_fillup_self,
-    "POST INTERVAL FILLUP SELF _DATE _DATE1" => \&_method_interval_fillup_self,
-    "DELETE INTERVAL FILLUP SELF _DATE _DATE1" => \&_method_interval_fillup_self,
+    "GET INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
+    "PUT INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
+    "POST INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
+    "DELETE INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
+    "GET INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
+    "PUT INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
+    "POST INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
+    "DELETE INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
+    "GET INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
+    "PUT INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
+    "POST INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
+    "DELETE INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
     "GET INTERVAL IID _NUM" => \&_method_interval_iid,
     "PUT INTERVAL IID _NUM" => \&_method_interval_iid,
     "POST INTERVAL IID _NUM" => \&_method_interval_iid,
@@ -635,6 +636,10 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH" => \&interval_promptdate,
     "INTERVAL FILLUP" => \&interval_promptdate,
     "EMPLOYEE_SPEC INTERVAL FILLUP" => \&interval_promptdate,
+    "INTERVAL FILLUP COMMIT" => \&interval_promptdate,
+    "EMPLOYEE_SPEC INTERVAL FILLUP COMMIT" => \&interval_promptdate,
+    "INTERVAL DELETE COMMIT" => \&interval_promptdate,
+    "EMPLOYEE_SPEC INTERVAL DELETE COMMIT" => \&interval_promptdate,
 
     "INTERVAL _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL _DATE" => \&interval_date,
@@ -642,6 +647,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE" => \&interval_date,
     "INTERVAL FILLUP _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE" => \&interval_date,
+    "INTERVAL FILLUP _DATE COMMIT" => \&interval_date,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE COMMIT" => \&interval_date,
     "INTERVAL DELETE _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL DELETE _DATE" => \&interval_date,
 
@@ -651,12 +658,20 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL FILLUP _DATE _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _DATE1" => \&interval_date_date1,
+    "INTERVAL FILLUP _DATE _DATE1 COMMIT" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _DATE1 COMMIT" => \&interval_date_date1,
+    "INTERVAL DELETE _DATE _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL DELETE _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL FETCH _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL FILLUP _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1" => \&interval_date_date1,
+    "INTERVAL FILLUP _DATE _HYPHEN _DATE1 COMMIT" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1 COMMIT" => \&interval_date_date1,
+    "INTERVAL DELETE _DATE _HYPHEN _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL DELETE _DATE _HYPHEN _DATE1" => \&interval_date_date1,
 
     "INTERVAL _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL _MONTH" => \&interval_month,
@@ -664,12 +679,20 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _MONTH" => \&interval_month,
     "INTERVAL FILLUP _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH" => \&interval_month,
+    "INTERVAL FILLUP _MONTH COMMIT" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH COMMIT" => \&interval_month,
+    "INTERVAL DELETE _MONTH" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL DELETE _MONTH" => \&interval_month,
     "INTERVAL _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL _MONTH _NUM" => \&interval_month,
     "INTERVAL FETCH _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL FETCH _MONTH _NUM" => \&interval_month,
     "INTERVAL FILLUP _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _NUM" => \&interval_month,
+    "INTERVAL FILLUP _MONTH _NUM COMMIT" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _NUM COMMIT" => \&interval_month,
+    "INTERVAL DELETE _MONTH _NUM" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL DELETE _MONTH _NUM" => \&interval_month,
 
     "INTERVAL _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL _NUM" => \&interval_num_num1,
@@ -677,12 +700,25 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _NUM" => \&interval_num_num1,
     "INTERVAL FILLUP _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM" => \&interval_num_num1,
+    "INTERVAL FILLUP _NUM COMMIT" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _NUM COMMIT" => \&interval_num_num1,
+    "INTERVAL DELETE _NUM" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL DELETE _NUM" => \&interval_num_num1,
     "INTERVAL _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL FETCH _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL FETCH _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL FILLUP _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM _NUM1" => \&interval_num_num1,
+    "INTERVAL FILLUP _NUM _NUM1 COMMIT" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _NUM _NUM1 COMMIT" => \&interval_num_num1,
+    "INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
+
+    "INTERVAL FILLUP _TSRANGE" => \&interval_fillup_tsrange,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE" => \&interval_fillup_tsrange,
+    "INTERVAL FILLUP _TSRANGE COMMIT" => \&interval_fillup_tsrange,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE COMMIT" => \&interval_fillup_tsrange,
 
     # add/insert new intervals
     "INTERVAL _TIME _TIME1 _TERM" => \&interval_new_time_time1,
